/**
 *
 * Beryl Logger
 *
 * beryl-error.h
 *
 * Copyright (c) 2007 Tom Watson. <beryl@mail.shadysidesupercomputingcenter.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */

/*
 * This file contains the beryl logger function definitions
 *
 * This file uses the following compiler defines
 *		BERYL_DEBUG		- adds extra information to the resulting output
 *							(file and line numbers)
 *		BERYL_RELEASE	- "compiles out" calls to info,debug, and vdebug levels
 *
 */
#ifndef BERYL_ERROR_H

#define BERYL_ERROR_H

#ifndef BERYL_DEBUG
#	define BLL_Critical			BLLCritical
#	define BLL_Warning			BLLWarning
#	define BLL_Info				BLLInfo
#	define BLL_Debug			BLLDebug
#	define BLL_VDebug			BLLVDebug
#else
#	define BLL_Critical			BLLCritical,__FILE__,__LINE__
#	define BLL_Warning			BLLWarning,__FILE__,__LINE__
#	define BLL_Info				BLLInfo,__FILE__,__LINE__
#	define BLL_Debug			BLLDebug,__FILE__,__LINE__
#	define BLL_VDebug			BLLVDebug,__FILE__,__LINE__
#endif

// pretty names
#define	pCritical(...)		blog(BLL_Critical,__VA_ARGS__)
#define	pWarning(...)		blog(BLL_Warning,__VA_ARGS__)
#define	pInfo(...)		blog(BLL_Info,__VA_ARGS__)
#define	pDebug(...)		blog(BLL_Debug,__VA_ARGS__)
#define	pVDebug(...)		blog(BLL_VDebug,__VA_ARGS__)


// levels
typedef enum
{
	BLLCritical,
	BLLWarning,
	BLLInfo,
	BLLDebug,
	BLLVDebug,
	BLLMax
} BLogLevel;

// Flags (must be power or two for masking)
typedef enum
{
	BLFNone = 0x00,
	BLFFlush = 0x01,			// flush after write
	BLFCritical2Stdout = 0x02,	// dump critical msgs to stdout
	BLFTimestamp = 0x04,		// show the time stamp
} BLogFlags;

// default flags
#define BLFDefaults	 (BLFCritical2Stdout)

// beryl log function 
int blog(BLogLevel level,
#ifdef BERYL_DEBUG
		 const char *file, unsigned int line,
#endif
		 const char *fmt, ...);

// function to return a readable string based on level
const char *blogLevel(BLogLevel level);

// function to set the log level
void blogSetLevel(BLogLevel level);

// function to increase log level
void blogIncreaseLevel(void);

// function to decrease log level
void blogDecreaseLevel(void);

// function to set logfile name
Bool blogSetFilename(const char *file);

// returns the current flag settings
unsigned int blogGetFlags(void);

// function to set the flags
void blogSetFlags(unsigned int flags);


#endif
